DROP TABLE IF EXISTS announcements;

CREATE TABLE announcements (
  id int(11) NOT NULL auto_increment,
  title varchar(250) NOT NULL,
  start_date int(11) NULL,
  end_date int(11) NULL,
  height int(11) NULL,
  width int(11) NULL,
  view varchar(250) NOT NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS attachments;

CREATE TABLE attachments (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  filename varchar(250) NOT NULL,
  size int(11) NOT NULL,
  created_on int(11) NOT NULL,
  project_id int(11) default NULL,
  case_id int(11) default NULL,
  test_change_id int(11) default NULL,
  user_id int(11) default NULL,
  PRIMARY KEY  (id),
  KEY ix_attachments_case_id (case_id),
  KEY ix_attachments_test_change_id (test_change_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS case_assocs;

CREATE TABLE case_assocs (
  id int(11) NOT NULL auto_increment,
  case_id int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  `value` int(11) NOT NULL,
  PRIMARY KEY (id),
  KEY ix_case_assocs_case_id (case_id)
) ENGINE=InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS case_changes;

CREATE TABLE case_changes (
  id int(11) NOT NULL auto_increment,
  case_id int(11) NOT NULL,
  type_id int(11) NOT NULL,
  created_on int(11) NOT NULL,
  user_id int(11) NOT NULL,
  changes longtext,
  PRIMARY KEY (id),
  KEY ix_case_changes_case_id (case_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS case_types;

CREATE TABLE case_types (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  is_default tinyint(1) NOT NULL,
  is_deleted tinyint(1) NOT NULL,  
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS cases;

CREATE TABLE cases (
  id int(11) NOT NULL auto_increment,
  section_id int(11) NOT NULL,
  title varchar(250) NOT NULL,
  display_order int(11) NOT NULL,
  priority_id int(11) NOT NULL,
  estimate int(11) default NULL,
  milestone_id int(11) default NULL,
  custom_preconds longtext,
  custom_steps longtext,
  custom_expected longtext,
  type_id int(11) NOT NULL,
  is_copy tinyint(1) NOT NULL,
  copyof_id int(11) default NULL,
  created_on int(11) NOT NULL,
  user_id int(11) NOT NULL,
  estimate_forecast int(11) default NULL,
  refs varchar(250) default NULL,
  suite_id int(11) NOT NULL,
  updated_on int(11) NOT NULL,
  updated_by int(11) NOT NULL,
  PRIMARY KEY  (id),
  KEY ix_cases_section_id (section_id),
  KEY ix_cases_suite_id (suite_id),
  KEY ix_cases_copyof_id (copyof_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS config_groups;

CREATE TABLE config_groups (
  id int(11) NOT NULL auto_increment,
  project_id int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  PRIMARY KEY  (id),
  KEY ix_config_groups_project_id (project_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS configs;

CREATE TABLE configs (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  group_id int(11) NOT NULL,
  PRIMARY KEY  (id),
  KEY ix_configs_group_id (group_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS defects;

CREATE TABLE defects (
  id int(11) NOT NULL auto_increment,
  defect_id varchar(250) NOT NULL,
  test_change_id int(11) NOT NULL,
  case_id int(11) NULL,
  project_id int(11) NOT NULL,
  PRIMARY KEY (id),
  KEY ix_defects_defect_id (defect_id),
  KEY ix_defects_test_change_id (test_change_id),
  KEY ix_defects_case_id (case_id)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS exports;

CREATE TABLE exports (
  id int(11) NOT NULL auto_increment,
  filename varchar(250) NOT NULL,
  size bigint(20) NOT NULL,
  created_on int(11) NOT NULL,
  PRIMARY KEY  (id),
  KEY ix_exports_created_on (created_on)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS fields;

CREATE TABLE fields (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  system_name varchar(250) NOT NULL,
  entity_id int(11) NOT NULL,
  label varchar(250) NOT NULL,
  description longtext,
  type_id int(11) NOT NULL,
  location_id int(11) NOT NULL,
  display_order int(11) NOT NULL,
  configs longtext NOT NULL,
  is_multi tinyint(1) NOT NULL,
  is_active tinyint(1) NOT NULL,
  status_id int(11) NOT NULL,
  is_system tinyint(1) NOT NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_fields_name (entity_id,name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS groups;

CREATE TABLE groups (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS group_users;

CREATE TABLE group_users (
  group_id int(11) NOT NULL,
  user_id int(11) NOT NULL,
  PRIMARY KEY  (group_id,user_id),
  KEY ix_group_users_user_id (user_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS jobs;

CREATE TABLE jobs (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  created_on int(11) NOT NULL,
  is_locked tinyint(1) NOT NULL,
  heartbeat int(11) NOT NULL,
  is_done tinyint(1) NOT NULL,
  PRIMARY KEY  (id),
  UNIQUE ux_jobs_name (name)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS message_recps;

CREATE TABLE message_recps (
  user_id int(11) NOT NULL,
  message_id int(11) NOT NULL,
  PRIMARY KEY  (message_id,user_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS messages;

CREATE TABLE messages (
  id int(11) NOT NULL auto_increment,
  `subject` varchar(250) NOT NULL,
  body longtext NOT NULL,
  created_on int(11) NOT NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS milestones;

CREATE TABLE milestones (
  id int(11) NOT NULL auto_increment,
  project_id int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  due_on int(11) default NULL,
  completed_on int(11) default NULL,
  is_completed tinyint(1) NOT NULL,
  description longtext,
  PRIMARY KEY  (id),
  KEY ix_milestones_project_id (project_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS preferences;

CREATE TABLE preferences (
  id int(11) NOT NULL auto_increment,
  user_id int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  `value` longtext,
  PRIMARY KEY  (id),
  KEY ix_preferences_user_id (user_id),
  UNIQUE KEY ux_preferences_name (user_id,name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS priorities;

CREATE TABLE priorities (
  id int(11) NOT NULL auto_increment,
  priority int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  short_name varchar(250) NOT NULL,
  is_default tinyint(1) NOT NULL,
  is_deleted tinyint(1) NOT NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS project_access;

CREATE TABLE project_access (
  project_id int(11) NOT NULL,
  user_id int(11) NOT NULL,
  access int(11) NOT NULL,
  role_id int(11) default NULL,
  PRIMARY KEY  (project_id,user_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS project_groups;

CREATE TABLE project_groups (
  project_id int(11) NOT NULL,
  group_id int(11) NOT NULL,
  access int(11) NOT NULL,
  role_id int(11) default NULL,
  PRIMARY KEY  (project_id,group_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS project_history;

CREATE TABLE project_history (
  id int(11) NOT NULL auto_increment,
  project_id int(11) NOT NULL,
  `action` int(11) NOT NULL,
  created_on int(11) NOT NULL,
  user_id int(11) NOT NULL,
  suite_id int(11) default NULL,
  milestone_id int(11) default NULL,
  run_id int(11) default NULL,
  `name` varchar(250) default NULL,
  is_deleted tinyint(1) NOT NULL,
  plan_id int(11) default NULL,
  PRIMARY KEY  (id),
  KEY ix_project_history_project_order (project_id,created_on)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS projects;

CREATE TABLE projects (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  announcement longtext,
  show_announcement tinyint(1) NOT NULL,
  defect_id_url varchar(250) default NULL,
  defect_add_url varchar(250) default NULL,
  default_access int(11) NOT NULL,
  default_role_id int(11) default NULL,
  reference_id_url varchar(250) default NULL,
  reference_add_url varchar(250) default NULL,
  defect_plugin varchar(250) default NULL,
  defect_config longtext,
  is_completed tinyint(1) NOT NULL,
  completed_on int(11) default NULL,
  defect_template longtext,
  suite_mode int(11) NOT NULL,
  master_id int(11) NULL,
  reference_plugin varchar(250) default NULL,
  reference_config longtext,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS refs;

CREATE TABLE refs (
  id int(11) NOT NULL auto_increment,
  reference_id varchar(250) NOT NULL,
  case_id int(11) NOT NULL,
  project_id int(11) NOT NULL,
  PRIMARY KEY (id),
  KEY ix_refs_reference_id (reference_id),
  KEY ix_refs_case_id (case_id)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS reports;

CREATE TABLE reports (
  id int(11) NOT NULL auto_increment,
  plugin varchar(250) NOT NULL,
  project_id int(11) NOT NULL,
  name varchar(250) NOT NULL,
  description longtext,
  access int(11) NOT NULL,
  created_by int(11) NOT NULL,
  created_on int(11) NOT NULL,
  executed_on int(11) NULL,
  execution_time int(11) NULL,
  dir varchar(250) NULL,
  formats longtext NOT NULL,
  system_options longtext,
  custom_options longtext,
  status int(11) NOT NULL,
  status_message longtext,
  status_trace longtext,
  is_locked tinyint(1) NOT NULL,
  heartbeat int(11) NOT NULL,
  PRIMARY KEY  (id),
  KEY ix_reports_project_id (project_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS report_jobs;

CREATE TABLE report_jobs (
  id int(11) NOT NULL auto_increment,
  plugin varchar(250) NOT NULL,
  project_id int(11) NOT NULL,
  created_by int(11) NOT NULL,
  created_on int(11) NOT NULL,
  executed_on int(11) NULL,
  system_options longtext,
  custom_options longtext,
  PRIMARY KEY  (id),
  KEY ix_report_jobs_project_id (project_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS roles;

CREATE TABLE roles (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  permissions int(11) NOT NULL,
  is_default int(11) NOT NULL,
  display_order int(11) NOT NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS runs;

CREATE TABLE runs (
  id int(11) NOT NULL auto_increment,
  suite_id int(11) default NULL,
  milestone_id int(11) default NULL,
  created_on int(11) NOT NULL,
  user_id int(11) NOT NULL,
  project_id int(11) NOT NULL,
  is_completed tinyint(1) NOT NULL,
  completed_on int(11) default NULL,
  include_all tinyint(1) NOT NULL,
  `name` varchar(250) NOT NULL,
  description longtext,
  passed_count int(11) NOT NULL default '0',
  retest_count int(11) NOT NULL default '0',
  failed_count int(11) NOT NULL default '0',
  untested_count int(11) NOT NULL default '0',
  assignedto_id int(11) default NULL,
  is_plan tinyint(1) NOT NULL default '0',
  plan_id int(11) default NULL,
  entry_id varchar(250) default NULL,
  entries longtext,
  config varchar(250) default NULL,
  config_ids varchar(250) default NULL,
  entry_index int(11) default NULL,
  blocked_count int(11) NOT NULL default '0',
  is_editable tinyint(1) NOT NULL,
  content_id int(11) default NULL,
  custom_status1_count int(11) NOT NULL default '0',
  custom_status2_count int(11) NOT NULL default '0',
  custom_status3_count int(11) NOT NULL default '0',
  custom_status4_count int(11) NOT NULL default '0',
  custom_status5_count int(11) NOT NULL default '0',
  custom_status6_count int(11) NOT NULL default '0',
  custom_status7_count int(11) NOT NULL default '0',
  PRIMARY KEY  (id),
  KEY ix_runs_project_id (project_id),
  KEY ix_runs_plan_id (plan_id),
  KEY ix_runs_milestone_id (milestone_id),
  KEY ix_runs_suite_id (suite_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS sections;

CREATE TABLE sections (
  id int(11) NOT NULL auto_increment,
  suite_id int(11) default NULL,
  `name` varchar(250) NOT NULL,
  display_order int(11) NOT NULL,
  is_copy tinyint(1) NOT NULL,
  copyof_id int(11) default NULL,
  parent_id int(11) default NULL,
  depth int(11) NOT NULL default '0',
  description longtext,  
  PRIMARY KEY  (id),
  KEY ix_sections_suite_id (suite_id),
  KEY ix_sections_copyof_id (copyof_id),
  KEY ix_sections_parent_id (parent_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS sessions;

CREATE TABLE sessions (
  session_id varchar(40) NOT NULL,
  ip_address varchar(16) NOT NULL,
  user_agent varchar(250) NOT NULL,
  last_activity int(10) NOT NULL,
  user_data longtext,
  id int(11) NOT NULL auto_increment,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_sessions_session_id (session_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS settings;

CREATE TABLE settings (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  `value` longtext,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_settings_name (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS subscriptions;

CREATE TABLE subscriptions (
  id int(11) NOT NULL auto_increment,
  user_id int(11) NOT NULL,
  is_subscribed tinyint(1) NOT NULL,
  test_id int(11) NOT NULL,
  run_id int(11) NOT NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_subscriptions_run_test (run_id,test_id,user_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS suites;

CREATE TABLE suites (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  project_id int(11) NOT NULL,
  description longtext,
  created_on int(11) NOT NULL,
  created_by int(11) NOT NULL,
  is_copy tinyint(1) NOT NULL,
  copyof_id int(11) default NULL,  
  is_master tinyint(1) NOT NULL,
  is_baseline tinyint(1) NOT NULL,
  parent_id int(11) default NULL,  
  is_completed tinyint(1) NOT NULL,
  completed_on int(11) NULL,
  PRIMARY KEY  (id),
  KEY ix_suites_project_id (project_id),
  KEY ix_suites_copyof_id (copyof_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS statuses;

CREATE TABLE statuses (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  system_name varchar(250) NOT NULL,
  label varchar(250) NOT NULL,
  color_dark int(11) NOT NULL,
  color_medium int(11) NOT NULL,
  color_bright int(11) NOT NULL,
  display_order int(11) NOT NULL,
  is_system tinyint(1) NOT NULL,
  is_active tinyint(1) NOT NULL,
  is_untested tinyint(1) NOT NULL,
  is_final tinyint(1) NOT NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_statuses_name (name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS task;

CREATE TABLE task (
  id int(11) NOT NULL,
  is_locked tinyint(1) NOT NULL,
  heartbeat int(11) default NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS test_assocs;

CREATE TABLE test_assocs (
  id int(11) NOT NULL auto_increment,
  test_change_id int(11) NOT NULL,
  test_id int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  `value` int(11) NOT NULL,
  PRIMARY KEY (id),
  KEY ix_test_assocs_test_change_id (test_change_id), 
  KEY ix_test_assocs_test_id (test_id)
) ENGINE=InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS test_activities;

CREATE TABLE test_activities (
  `date` int(11) NOT NULL,
  project_id int(11) NOT NULL,
  run_id int(11) NOT NULL,
  passed_count int(11) NOT NULL,
  retest_count int(11) NOT NULL,
  failed_count int(11) NOT NULL,
  untested_count int(11) NOT NULL,
  blocked_count int(11) NOT NULL,
  custom_status1_count int(11) NOT NULL,
  custom_status2_count int(11) NOT NULL,
  custom_status3_count int(11) NOT NULL,
  custom_status4_count int(11) NOT NULL,
  custom_status5_count int(11) NOT NULL,
  custom_status6_count int(11) NOT NULL,
  custom_status7_count int(11) NOT NULL,
  PRIMARY KEY (`date`,project_id,run_id),
  KEY ix_test_activities_run_id (run_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS test_changes;

CREATE TABLE test_changes (
  id int(11) NOT NULL auto_increment,
  test_id int(11) NOT NULL,
  user_id int(11) NOT NULL,
  status_id int(11) default NULL,
  `comment` longtext,
  version varchar(250) default NULL,
  elapsed int(11) default NULL,
  defects varchar(250) default NULL,
  created_on int(11) NOT NULL,
  assignedto_id int(11) default NULL,
  unassigned tinyint(1) NOT NULL,
  project_id int(11) NOT NULL,
  run_id int(11) NOT NULL,
  is_selected tinyint(1) NOT NULL,
  caching int(11) NOT NULL,
  PRIMARY KEY  (id),
  KEY ix_test_changes_test_id (test_id),
  KEY ix_test_changes_project_order (project_id,is_selected,created_on),
  KEY ix_test_changes_run_order (run_id,is_selected,created_on)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS test_progress;

CREATE TABLE test_progress (
  `date` int(11) NOT NULL,
  project_id int(11) NOT NULL,
  run_id int(11) NOT NULL,
  tests int(11) NOT NULL,
  forecasts int(11) NOT NULL,
  PRIMARY KEY (`date`,project_id,run_id),
  KEY ix_test_progress_run_id (run_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS test_timers;

CREATE TABLE test_timers (
  test_id int(11) NOT NULL,
  user_id int(11) NOT NULL,
  started_on int(11) NOT NULL,
  elapsed int(11) NOT NULL,
  is_paused tinyint(1) NOT NULL,
  PRIMARY KEY  (test_id,user_id),
  KEY ix_test_timers_user_id (user_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS tests;

CREATE TABLE tests (
  id int(11) NOT NULL auto_increment,
  run_id int(11) NOT NULL,
  case_id int(11) NULL,
  status_id int(11) NOT NULL,
  assignedto_id int(11) default NULL,
  is_selected tinyint(1) NOT NULL,
  last_status_change_id int(11) default NULL,
  is_completed tinyint(1) NOT NULL,
  in_progress int(11) NOT NULL,
  in_progress_by int(11) default NULL,
  content_id int(11) NULL,
  tested_by int(11) default NULL,
  tested_on int(11) default NULL,
  PRIMARY KEY  (id),
  KEY ix_tests_run_id (run_id),
  KEY ix_tests_case_id (case_id,is_selected),
  KEY ix_tests_content_id (content_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS uiscripts;

CREATE TABLE uiscripts (
  id int(11) NOT NULL auto_increment,
  `name` varchar( 250 ) NOT NULL,
  is_active tinyint(1) NOT NULL,
  includes varchar( 250 ) default NULL,
  excludes varchar( 250 ) default NULL,
  meta longtext default NULL,
  js longtext default NULL,
  css longtext default NULL,
  PRIMARY KEY  (id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS users;

CREATE TABLE users (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  email varchar(250) NOT NULL,
  is_admin tinyint(1) NOT NULL,
  salt varchar(250) NOT NULL,
  `hash` varchar(250) NOT NULL,
  is_active tinyint(1) NOT NULL,
  rememberme varchar(250) NOT NULL,
  locale varchar(250) default NULL,
  `language` varchar(250) default NULL,
  notifications tinyint(1) NOT NULL,
  csrf varchar(250) NOT NULL,
  role_id int(11) NOT NULL,
  login_token varchar(250) default NULL,
  timezone varchar(250) default NULL,
  login_token_until int(11) default NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_users_email (email)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS user_columns;

CREATE TABLE user_columns (
  user_id int(11) NOT NULL,
  project_id int(11) NOT NULL,
  area_id int(11) NOT NULL,
  columns longtext NOT NULL,
  group_by varchar(250) NOT NULL,
  group_order varchar(250) NOT NULL,
  PRIMARY KEY (user_id, project_id, area_id)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS user_exports;

CREATE TABLE user_exports (
  user_id int(11) NOT NULL,
  project_id int(11) NOT NULL,
  area_id int(11) NOT NULL,
  format varchar(250) NOT NULL,
  options longtext NOT NULL,
  PRIMARY KEY (user_id, project_id, area_id, format)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS user_fields;

CREATE TABLE user_fields (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  system_name varchar(250) NOT NULL,
  label varchar(250) NOT NULL,
  description longtext,
  type_id int(11) NOT NULL,
  fallback varchar(250) NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_user_fields_name (name)  
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS user_filters;

CREATE TABLE user_filters (
  user_id int(11) NOT NULL,
  project_id int(11) NOT NULL,
  area_id int(11) NOT NULL,
  filters longtext NOT NULL,
  PRIMARY KEY (user_id, project_id, area_id)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;

DROP TABLE IF EXISTS user_logins;

CREATE TABLE user_logins (
  id int(11) NOT NULL auto_increment,
  `name` varchar(250) NOT NULL,
  created_on int(11) NOT NULL,  
  updated_on int(11) NOT NULL,
  attempts int(11) NOT NULL,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_user_logins_name (name)  
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS user_settings;

CREATE TABLE user_settings (
  id int(11) NOT NULL auto_increment,
  user_id int(11) NOT NULL,
  `name` varchar(250) NOT NULL,
  `value` longtext,
  PRIMARY KEY  (id),
  UNIQUE KEY ux_user_settings_name (user_id,name) 
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

DROP TABLE IF EXISTS user_tokens;

CREATE TABLE user_tokens (
  id int(11) NOT NULL auto_increment,
  user_id int(11) NOT NULL,
  type_id int(11) NOT NULL,
  name varchar(250) NULL,
  series varchar(250) NULL,
  hash varchar(250) NOT NULL,
  created_on int(11) NOT NULL, 
  expires_on int(11) NULL,
  PRIMARY KEY (id),
  KEY ix_user_tokens_user_id (user_id)
) ENGINE = InnoDB CHARACTER SET utf8 COLLATE utf8_unicode_ci;
INSERT INTO task (id, is_locked, heartbeat) VALUES (1, 0, 0);

-- Add the priorities
INSERT INTO priorities (id, priority, name, short_name, is_default, is_deleted) VALUES (1, 1, 'Low', 'Low', 0, 0);

INSERT INTO priorities (id, priority, name, short_name, is_default, is_deleted) VALUES (2, 2, 'Medium', 'Medium', 1, 0);

INSERT INTO priorities (id, priority, name, short_name, is_default, is_deleted) VALUES (3, 3, 'High', 'High', 0, 0);

INSERT INTO priorities (id, priority, name, short_name, is_default, is_deleted) VALUES (4, 4, 'Critical', 'Critical', 0, 0);

-- Add the initial cases types
INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (1, 'Acceptance', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (2, 'Accessibility', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (3, 'Automated', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (4, 'Compatibility', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (5, 'Destructive', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (6, 'Functional', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (7, 'Other', 1, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (8, 'Performance', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (9, 'Regression', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (10, 'Security', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (11, 'Smoke & Sanity', 0, 0);

INSERT INTO case_types (id, name, is_default, is_deleted) VALUES (12, 'Usability', 0, 0);

-- Add the initial default roles
INSERT INTO roles (id, name, permissions, is_default, display_order) VALUES (1, 'Lead', 262143, 1, 18);

INSERT INTO roles (id, name, permissions, is_default, display_order) VALUES (2, 'Designer', 258636, 0, 10);

INSERT INTO roles (id, name, permissions, is_default, display_order) VALUES (3, 'Tester', 258624, 0, 8);

INSERT INTO roles (id, name, permissions, is_default, display_order) VALUES (4, 'Read-only', 0, 0, 0);

-- Add the initial (custom/system) fields
INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(1, 'preconds', 'custom_preconds', 1, 'Preconditions', 'The preconditions of this test case. Reference other test cases with [C#] (e.g. [C17]).', 3, 2, 1, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false,"default_value":"","format":"markdown","rows":"7"},"id":"4be1344d55d11"}]', 0, 1, 1, 0);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(2, 'steps', 'custom_steps', 1, 'Steps', 'The required steps to execute the test case.', 3, 2, 2, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false,"default_value":"","format":"markdown","rows":"7"},"id":"4be97c65ea2fd"}]', 0, 1, 1, 0);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(3, 'expected', 'custom_expected', 1, 'Expected Result', 'The expected result after executing the test case.', 3, 2, 3, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false,"default_value":"","format":"markdown","rows":"7"},"id":"4be1345cafd07"}]', 0, 1, 1, 0);

INSERT INTO fields
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(4, 'dc330d77', 'estimate', 1, 'Estimate', null, 1, 1, 1, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false},"id":"4be97c65ea2fd"}]', 0, 1, 1, 1);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(5, 'ddfe71c8', 'milestone_id', 1, 'Milestone', null, 9, 1, 2, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false},"id":"4be97c65ea2fd"}]', 0, 0, 1, 1);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(6, 'c4bd4336', 'refs', 1, 'References', null, 1, 1, 3, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false},"id":"4be97c65ea2fd"}]', 0, 1, 1, 1);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(7, 'd4d1e651', 'version', 2, 'Version', null, 1, 4, 2, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false},"id":"4be97c65ea2fd"}]', 0, 1, 1, 1);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(8, 'e7c13ac2', 'elapsed', 2, 'Elapsed', null, 1, 4, 3, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false},"id":"4be97c65ea2fd"}]', 0, 1, 1, 1);

INSERT INTO fields 
		(id, name, system_name, entity_id, label, description, type_id, location_id, display_order, configs, is_multi, is_active, status_id, is_system) 
	VALUES 
		(9, 'a6637b4f', 'defects', 2, 'Defects', null, 1, 4, 4, '[{"context":{"is_global":true,"project_ids":null},"options":{"is_required":false},"id":"4be97c65ea2fd"}]', 0, 1, 1, 1);

-- Add the statuses
INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (1, 'passed', 'passed', 'Passed', 6667107, 9820525, 12709313, 1, 1, 1, 0, 1);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (2, 'blocked', 'blocked', 'Blocked', 9474192, 13684944, 14737632, 2, 1, 1, 0, 1);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (3, 'untested', 'untested', 'Untested', 11579568, 15395562, 15790320, 3, 1, 1, 1, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (4, 'retest', 'retest', 'Retest', 13026868, 15593088, 16448182, 4, 1, 1, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (5, 'failed', 'failed', 'Failed', 14250867, 15829135, 16631751, 5, 1, 1, 0, 1);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (6, 'custom_status1', 'custom_status1', 'Unnamed 1', 0, 10526880, 13684944, 6, 0, 0, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (7, 'custom_status2', 'custom_status2', 'Unnamed 2', 0, 10526880, 13684944, 7, 0, 0, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (8, 'custom_status3', 'custom_status3', 'Unnamed 3', 0, 10526880, 13684944, 8, 0, 0, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (9, 'custom_status4', 'custom_status4', 'Unnamed 4', 0, 10526880, 13684944, 9, 0, 0, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (10, 'custom_status5', 'custom_status5', 'Unnamed 5', 0, 10526880, 13684944, 10, 0, 0, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (11, 'custom_status6', 'custom_status6', 'Unnamed 6', 0, 10526880, 13684944, 11, 0, 0, 0, 0);

INSERT INTO statuses (id, name, system_name, label, color_dark, color_medium, color_bright, display_order, is_system, is_active, is_untested, is_final) VALUES (12, 'custom_status7', 'custom_status7', 'Unnamed 7', 0, 10526880, 13684944, 12, 0, 0, 0, 0);

